(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 11.0' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1064,         20]
NotebookDataLength[     23093,        551]
NotebookOptionsPosition[     23451,        540]
NotebookOutlinePosition[     23916,        560]
CellTagsIndexPosition[     23873,        557]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Couple Moment\n",
 StyleBox["Zhelong He, Marek-Jerzy Pindera \nUniversity of Virginia, \
2017-08-30",
  FontSize->16,
  FontColor->GrayLevel[0]]
}], "Title",
 TextAlignment->Center],

Cell["\<\
A couple is defined as two parallel forces that have the same magnitude, but \
opposite directions, and are separated by a perpendicular distance d. Since \
the resultant force is zero, the only effect of a couple is to produce an \
actual rotation, or if no movement is possible, there is a tendency of \
rotation in a specified direction.
The moment produced by a couple is called a couple moment. We can determine \
its value by finding the sum of the moments of both couple forces about any \
arbitrary point. The magnitude of moment can be defined as \
\>", "Text"],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{"M", "=", 
   StyleBox["Fd",
    FontSlant->"Italic"]}], TraditionalForm]]]], "Text",
 TextAlignment->Center],

Cell["\<\
Where F is the magnitude of one of the forces and d is the perpendicular \
distance or moment arm between the forces.
In the following example, a couple act on a gear, in which we can define the \
acting point of each force, as well as the magnitude and direction of the \
force, and see the effect of such moment on the gear. \
\>", "Text"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`f$$ = 0, $CellContext`opa4$$ = 
    0, $CellContext`ra$$ = 0, $CellContext`rb$$ = 
    0, $CellContext`\[Theta]a$$ = 0, $CellContext`\[Theta]b$$ = 
    0, $CellContext`\[Phi]d$$ = 0, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`ra$$], 0, 
       Row[{
         Text[
          Style["Radial coordinate", 12]], 
         Spacer[5], 
         Text[
          Style[
           Subscript[$CellContext`r, $CellContext`A], 12]], 
         Spacer[2.5]}]}, 0, 3}, {{
       Hold[$CellContext`\[Theta]a$$], 0, 
       Row[{
         Text[
          Style["Angular coordinate", 12]], 
         Spacer[5], 
         Text[
          Style[
           Subscript[$CellContext`\[Theta], $CellContext`A], 12]], 
         Spacer[3], "(\[Degree])"}]}, 0, 360}, {{
       Hold[$CellContext`rb$$], 0, 
       Row[{
         Text[
          Style["Radial coordinate", 12]], 
         Spacer[5], 
         Text[
          Style[
           Subscript[$CellContext`r, $CellContext`B], 12]], 
         Spacer[3.5]}]}, 0, 3}, {{
       Hold[$CellContext`\[Theta]b$$], 0, 
       Row[{
         Text[
          Style["Angular coordinate", 12]], 
         Spacer[6.5], 
         Text[
          Style[
           Subscript[$CellContext`\[Theta], $CellContext`B], 12]], 
         Spacer[3], "(\[Degree])"}]}, 0, 360}, {{
       Hold[$CellContext`f$$], 0, 
       Row[{
         Text[
          Style["Magnitude", 12]]}]}, 0, 5}, {{
       Hold[$CellContext`\[Phi]d$$], 0, 
       Row[{
         Text[
          Style["Orientation", 12]], 
         Spacer[66], "(\[Degree])", 
         Spacer[0]}]}, 0, 360}, {{
       Hold[$CellContext`opa4$$], 0, 
       Row[{
         Text[
          Style["Distance between", 12]], 
         Spacer[5], 
         Text[
          Style[
           Subscript[$CellContext`F, $CellContext`A], 12]], 
         Spacer[5], 
         Text[
          Style["and", 12]], 
         Spacer[5], 
         Text[
          Style[
           Subscript[$CellContext`F, $CellContext`B], 12]], " :", 
         Spacer[25.5]}]}, {1 -> "On", 0 -> "Off"}}, {
      Hold[
       Grid[{{
          Row[{
            Text[
             Style[
              Subscript[$CellContext`F, $CellContext`A], 12]], 
            Spacer[3], 
            Text[
             Style["location :", 12]], 
            Spacer[20], 
            Manipulate`Place[1], 
            Spacer[0.5], 
            Manipulate`Place[2]}]}, {
          Row[{
            Text[
             Style[
              Subscript[$CellContext`F, $CellContext`B], 12]], 
            Spacer[5], 
            Text[
             Style["location :", 12]], 
            Spacer[20], 
            Manipulate`Place[3], 
            Manipulate`Place[4]}]}, {
          Row[{
            Text[
             Style[
              Subscript[$CellContext`F, $CellContext`A], 12]], 
            Spacer[3], 
            Text[
             Style["specification :", 12]], 
            Spacer[52.5], 
            Manipulate`Place[5], 
            Manipulate`Place[6]}]}, {
          Row[{
            Manipulate`Place[7], 
            Spacer[94], 
            Dynamic[
             If[
              
              And[$CellContext`opa4$$ == 1, $CellContext`f$$ != 
               0], $CellContext`temp1 = Row[{
                 Text[
                  Style["Forces distance = ", 12]], 
                 Dynamic[
                  NumberForm[
                   N[
                    
                    Norm[{$CellContext`rb$$ 
                    Cos[$CellContext`\[Theta]b$$ Degree] - $CellContext`ra$$ 
                    Cos[$CellContext`\[Theta]a$$ Degree], $CellContext`rb$$ 
                    Sin[$CellContext`\[Theta]b$$ Degree] - $CellContext`ra$$ 
                    Sin[$CellContext`\[Theta]a$$ Degree]} - 
                    Projection[{$CellContext`rb$$ 
                    Cos[$CellContext`\[Theta]b$$ Degree] - $CellContext`ra$$ 
                    Cos[$CellContext`\[Theta]a$$ Degree], $CellContext`rb$$ 
                    Sin[$CellContext`\[Theta]b$$ Degree] - $CellContext`ra$$ 
                    Sin[$CellContext`\[Theta]a$$ Degree]}, {$CellContext`f$$ 
                    Cos[$CellContext`\[Phi]d$$ Degree], $CellContext`f$$ 
                    Sin[$CellContext`\[Phi]d$$ Degree]}]]], {3, 2}]]}], 
              Invisible[$CellContext`temp1]]]}]}}, Alignment -> Left, 
        Spacings -> {Automatic, 0.5}]], Manipulate`Dump`ThisIsNotAControl}}, 
    Typeset`size$$ = {975., {293., 302.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`ra$31502$$ = 0, $CellContext`\[Theta]a$31503$$ = 
    0, $CellContext`rb$31504$$ = 0, $CellContext`\[Theta]b$31505$$ = 
    0, $CellContext`f$31506$$ = 0, $CellContext`\[Phi]d$31507$$ = 
    0, $CellContext`opa4$31508$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`f$$ = 0, $CellContext`opa4$$ = 
        0, $CellContext`ra$$ = 0, $CellContext`rb$$ = 
        0, $CellContext`\[Theta]a$$ = 0, $CellContext`\[Theta]b$$ = 
        0, $CellContext`\[Phi]d$$ = 0}, "ControllerVariables" :> {
        Hold[$CellContext`ra$$, $CellContext`ra$31502$$, 0], 
        Hold[$CellContext`\[Theta]a$$, $CellContext`\[Theta]a$31503$$, 0], 
        Hold[$CellContext`rb$$, $CellContext`rb$31504$$, 0], 
        Hold[$CellContext`\[Theta]b$$, $CellContext`\[Theta]b$31505$$, 0], 
        Hold[$CellContext`f$$, $CellContext`f$31506$$, 0], 
        Hold[$CellContext`\[Phi]d$$, $CellContext`\[Phi]d$31507$$, 0], 
        Hold[$CellContext`opa4$$, $CellContext`opa4$31508$$, False]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`size$, $CellContext`\[Theta]$, \
$CellContext`\[Phi]$, $CellContext`\[Alpha]$, $CellContext`\[Beta]$, \
$CellContext`\[Gamma]$, $CellContext`\[Psi]$, $CellContext`m$, \
$CellContext`r$, $CellContext`pa$, $CellContext`pb$, $CellContext`AB$, \
$CellContext`dAB$, $CellContext`fa$, $CellContext`p1$, $CellContext`p2$, \
$CellContext`p3$, $CellContext`p4$, $CellContext`Ma$, $CellContext`Mb$, \
$CellContext`M$, $CellContext`I0$, $CellContext`t$, $CellContext`ts$, \
$CellContext`te$, $CellContext`N0$, $CellContext`mg$, $CellContext`h0$, \
$CellContext`label$, $CellContext`dwf1$, $CellContext`dwf2$, \
$CellContext`dwf3$, $CellContext`dwf4$, $CellContext`dw1$, $CellContext`an$}, \
$CellContext`\[Alpha]$ = ($CellContext`\[Theta]a$$/180) 
          Pi; $CellContext`\[Beta]$ = ($CellContext`\[Theta]b$$/180) 
          Pi; $CellContext`\[Phi]$ = ($CellContext`\[Phi]d$$/180) 
          Pi; $CellContext`m$ = 3; $CellContext`r$ = 3; $CellContext`size$ = 
         4; $CellContext`ts$ = 0; $CellContext`te$ = 
         15; $CellContext`I0$ = ((1/
            2) $CellContext`m$) $CellContext`r$^2; $CellContext`pa$ = \
{$CellContext`ra$$ Cos[$CellContext`\[Alpha]$], $CellContext`ra$$ 
           Sin[$CellContext`\[Alpha]$]}; $CellContext`pb$ = \
{$CellContext`rb$$ Cos[$CellContext`\[Beta]$], $CellContext`rb$$ 
           Sin[$CellContext`\[Beta]$]}; $CellContext`fa$ = {$CellContext`f$$ 
           Cos[$CellContext`\[Phi]$], $CellContext`f$$ 
           Sin[$CellContext`\[Phi]$]}; $CellContext`AB$ = $CellContext`pb$ - \
$CellContext`pa$; $CellContext`dAB$ = $CellContext`AB$ - 
          Projection[$CellContext`AB$, $CellContext`fa$]; $CellContext`Ma$ = \
($CellContext`ra$$ $CellContext`f$$) 
          Sin[$CellContext`\[Phi]$ - $CellContext`\[Alpha]$]; \
$CellContext`Mb$ = ((-$CellContext`rb$$) $CellContext`f$$) 
          Sin[$CellContext`\[Phi]$ - $CellContext`\[Beta]$]; $CellContext`M$ = \
$CellContext`Ma$ + $CellContext`Mb$; $CellContext`p1$ = $CellContext`pa$ + \
$CellContext`dAB$; $CellContext`p2$ = $CellContext`pa$ + 
          0.85 $CellContext`dAB$; $CellContext`p3$ = If[
           
           Or[$CellContext`AB$ == {0, 0}, $CellContext`fa$ == {0, 
             0}], $CellContext`pa$ + $CellContext`dAB$, $CellContext`pa$ + \
$CellContext`dAB$ + (0.15 Norm[$CellContext`dAB$]) 
            Normalize[$CellContext`fa$]]; $CellContext`p4$ = $CellContext`p2$ + \
$CellContext`p3$ - $CellContext`p1$; $CellContext`N0$ = 
         10; $CellContext`\[Psi]$ = ((360/$CellContext`N0$)/180) 
          Pi; $CellContext`h0$ = 0.15 $CellContext`r$; $CellContext`mg$ = 
         Table[$CellContext`i, {$CellContext`i, 0, $CellContext`N0$ - 1, 
            1}]; $CellContext`\[Gamma]$ = NDSolveValue[{$CellContext`I0$ D[
               $CellContext`\[Theta]$[$CellContext`t$], {$CellContext`t$, 
                2}] == $CellContext`M$, $CellContext`\[Theta]$[0] == 0, 
            Derivative[1][$CellContext`\[Theta]$][0] == 
            0}, $CellContext`\[Theta]$, {$CellContext`t$, $CellContext`ts$, \
$CellContext`te$}]; $CellContext`label$ = Text[
           Style[
            Row[{"t  = ", 
              NumberForm[$CellContext`t$, {4, 2}], 
              Spacer[15], 
              "\!\(\*\nStyleBox[\"M\",\nFontSlant->\"Italic\"]\)  = ", 
              NumberForm[
               N[$CellContext`M$], {3, 2}]}], 12]]; $CellContext`dwf1$ = {
           Thickness[0.004], 
           Map[
           Line[{{$CellContext`r$ 
               Cos[# $CellContext`\[Psi]$ - (1/
                  4) $CellContext`\[Psi]$], $CellContext`r$ 
               Sin[# $CellContext`\[Psi]$ - (1/
                  4) $CellContext`\[Psi]$]}, {$CellContext`r$ 
                Cos[# $CellContext`\[Psi]$ - (1/
                   4) $CellContext`\[Psi]$] + $CellContext`h0$ 
                Cos[# $CellContext`\[Psi]$], $CellContext`r$ 
                Sin[# $CellContext`\[Psi]$ - (1/
                   4) $CellContext`\[Psi]$] + $CellContext`h0$ 
                Sin[# $CellContext`\[Psi]$]}}]& , $CellContext`mg$], 
           Map[
           Line[{{$CellContext`r$ 
               Cos[# $CellContext`\[Psi]$ + (1/
                   4) $CellContext`\[Psi]$], $CellContext`r$ 
               Sin[# $CellContext`\[Psi]$ + (1/
                   4) $CellContext`\[Psi]$]}, {$CellContext`r$ 
                Cos[# $CellContext`\[Psi]$ + (1/
                    4) $CellContext`\[Psi]$] + $CellContext`h0$ 
                Cos[# $CellContext`\[Psi]$], $CellContext`r$ 
                Sin[# $CellContext`\[Psi]$ + (1/
                    4) $CellContext`\[Psi]$] + $CellContext`h0$ 
                Sin[# $CellContext`\[Psi]$]}}]& , $CellContext`mg$], 
           Map[
           Line[{{$CellContext`r$ 
                Cos[# $CellContext`\[Psi]$ - (1/
                   4) $CellContext`\[Psi]$] + $CellContext`h0$ 
                Cos[# $CellContext`\[Psi]$], $CellContext`r$ 
                Sin[# $CellContext`\[Psi]$ - (1/
                   4) $CellContext`\[Psi]$] + $CellContext`h0$ 
                Sin[# $CellContext`\[Psi]$]}, {$CellContext`r$ 
                Cos[# $CellContext`\[Psi]$ + (1/
                    4) $CellContext`\[Psi]$] + $CellContext`h0$ 
                Cos[# $CellContext`\[Psi]$], $CellContext`r$ 
                Sin[# $CellContext`\[Psi]$ + (1/
                    4) $CellContext`\[Psi]$] + $CellContext`h0$ 
                Sin[# $CellContext`\[Psi]$]}}]& , $CellContext`mg$], 
           Map[
           Circle[{0, 
             0}, $CellContext`r$, {# $CellContext`\[Psi]$ - (1/
               2) $CellContext`\[Psi]$, # $CellContext`\[Psi]$ - (1/
               4) $CellContext`\[Psi]$}]& , $CellContext`mg$], 
           Map[
           Circle[{0, 
             0}, $CellContext`r$, {# $CellContext`\[Psi]$ + (1/
                4) $CellContext`\[Psi]$, # $CellContext`\[Psi]$ + (1/
                2) $CellContext`\[Psi]$}]& , $CellContext`mg$], Gray, 
           Disk[{0, 0}, 0.15]}; $CellContext`dwf2$ = {Red, 
           Thickness[0.004], 
           Arrowheads[0.02], 
           Arrow[{{$CellContext`pa$, $CellContext`pa$ + $CellContext`fa$}}], 
           Arrow[{{$CellContext`pb$, $CellContext`pb$ - $CellContext`fa$}}], 
           PointSize[0.01], 
           Point[{$CellContext`pa$, $CellContext`pb$}], 
           Text[
           "\!\(\*\nStyleBox[\"A\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", $CellContext`pa$ + {0, 0.4}], 
           Text[
           "\!\(\*\nStyleBox[\"B\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", $CellContext`pb$ - {0, 0.4}]}; $CellContext`dwf3$ = {
           Opacity[
            Boole[$CellContext`M$ != 0]], 
           Thickness[0.004], 
           Arrowheads[0.015], 
           Arrow[
            Map[N[
              Table[{
                  Cos[$CellContext`k], 
                  Sin[$CellContext`k]} Part[#, 2] + 
               Part[#, 1], {$CellContext`k, 
                Part[#, 3], 
                Part[#, 4], (Part[#, 4] - Part[#, 3])/Part[#, 5]}]]& , {{{0, 
               0}, 0.3, 0, $CellContext`M$ + 10^(-6), 100}}]], 
           Text[
           "\!\(\*\nStyleBox[\"M\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {0, -0.7}]}; $CellContext`dwf4$ = {
           Opacity[
            Boole[
             And[$CellContext`opa4$$ == 1, $CellContext`f$$ != 0]]], Red, 
           Dashed, 
           Thickness[0.002], 
           Line[{$CellContext`pa$ + (2 $CellContext`r$) {
                Cos[$CellContext`\[Phi]$], 
                Sin[$CellContext`\[Phi]$]}, $CellContext`pa$ - (
              2 $CellContext`r$) {
               Cos[$CellContext`\[Phi]$], 
               Sin[$CellContext`\[Phi]$]}}], 
           Line[{$CellContext`pb$ - (2 $CellContext`r$) {
               Cos[$CellContext`\[Phi]$], 
               Sin[$CellContext`\[Phi]$]}, $CellContext`pb$ + (
               2 $CellContext`r$) {
                Cos[$CellContext`\[Phi]$], 
                Sin[$CellContext`\[Phi]$]}}], Black, 
           Thickness[0.004], 
           Line[{$CellContext`pa$, $CellContext`pa$ + $CellContext`dAB$}], 
           Dashing[{}], 
           Line[{$CellContext`p4$, $CellContext`p2$}], 
           Line[{$CellContext`p4$, $CellContext`p3$}]}; $CellContext`dw1$ = 
         Graphics[{
            
            Rotate[{$CellContext`dwf1$, $CellContext`dwf2$, \
$CellContext`dwf4$}, 
             $CellContext`\[Gamma]$[$CellContext`t$], {0, 
             0}], $CellContext`dwf3$}, 
           PlotRange -> {{(-2) $CellContext`size$, 
              2 $CellContext`size$}, {-$CellContext`size$, \
$CellContext`size$}}, ImageSize -> 600, Frame -> False, PlotLabel -> 
           Pane[$CellContext`label$, Alignment -> {Center, Top}, ImageSize -> 
             300]]; $CellContext`an$ = Animate[
           Evaluate[
            
            ReplaceAll[$CellContext`dw1$, {$CellContext`t$ -> \
$CellContext`time}]], {{$CellContext`time, $CellContext`ts$, 
             "t"}, $CellContext`ts$, $CellContext`te$}, 
           DefaultDuration -> $CellContext`te$, AnimationRunning -> False, 
           ImageMargins -> Small]; 
        Pane[$CellContext`an$, {650, Automatic}, Alignment -> Center]], 
      "Specifications" :> {{{$CellContext`ra$$, 0, 
          Row[{
            Text[
             Style["Radial coordinate", 12]], 
            Spacer[5], 
            Text[
             Style[
              Subscript[$CellContext`r, $CellContext`A], 12]], 
            Spacer[2.5]}]}, 0, 3, ImageSize -> Small, Appearance -> "Labeled",
          ControlPlacement -> 1}, {{$CellContext`\[Theta]a$$, 0, 
          Row[{
            Text[
             Style["Angular coordinate", 12]], 
            Spacer[5], 
            Text[
             Style[
              Subscript[$CellContext`\[Theta], $CellContext`A], 12]], 
            Spacer[3], "(\[Degree])"}]}, 0, 360, ImageSize -> Small, 
         Appearance -> "Labeled", ControlPlacement -> 
         2}, {{$CellContext`rb$$, 0, 
          Row[{
            Text[
             Style["Radial coordinate", 12]], 
            Spacer[5], 
            Text[
             Style[
              Subscript[$CellContext`r, $CellContext`B], 12]], 
            Spacer[3.5]}]}, 0, 3, ImageSize -> Small, Appearance -> "Labeled",
          ControlPlacement -> 3}, {{$CellContext`\[Theta]b$$, 0, 
          Row[{
            Text[
             Style["Angular coordinate", 12]], 
            Spacer[6.5], 
            Text[
             Style[
              Subscript[$CellContext`\[Theta], $CellContext`B], 12]], 
            Spacer[3], "(\[Degree])"}]}, 0, 360, ImageSize -> Small, 
         Appearance -> "Labeled", ControlPlacement -> 
         4}, {{$CellContext`f$$, 0, 
          Row[{
            Text[
             Style["Magnitude", 12]]}]}, 0, 5, ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 5}, {{$CellContext`\[Phi]d$$, 0, 
          Row[{
            Text[
             Style["Orientation", 12]], 
            Spacer[66], "(\[Degree])", 
            Spacer[0]}]}, 0, 360, ImageSize -> Small, Appearance -> "Labeled",
          ControlPlacement -> 6}, {{$CellContext`opa4$$, 0, 
          Row[{
            Text[
             Style["Distance between", 12]], 
            Spacer[5], 
            Text[
             Style[
              Subscript[$CellContext`F, $CellContext`A], 12]], 
            Spacer[5], 
            Text[
             Style["and", 12]], 
            Spacer[5], 
            Text[
             Style[
              Subscript[$CellContext`F, $CellContext`B], 12]], " :", 
            Spacer[25.5]}]}, {1 -> "On", 0 -> "Off"}, ControlType -> 
         RadioButton, ControlPlacement -> 7}, 
        Grid[{{
           Row[{
             Text[
              Style[
               Subscript[$CellContext`F, $CellContext`A], 12]], 
             Spacer[3], 
             Text[
              Style["location :", 12]], 
             Spacer[20], 
             Manipulate`Place[1], 
             Spacer[0.5], 
             Manipulate`Place[2]}]}, {
           Row[{
             Text[
              Style[
               Subscript[$CellContext`F, $CellContext`B], 12]], 
             Spacer[5], 
             Text[
              Style["location :", 12]], 
             Spacer[20], 
             Manipulate`Place[3], 
             Manipulate`Place[4]}]}, {
           Row[{
             Text[
              Style[
               Subscript[$CellContext`F, $CellContext`A], 12]], 
             Spacer[3], 
             Text[
              Style["specification :", 12]], 
             Spacer[52.5], 
             Manipulate`Place[5], 
             Manipulate`Place[6]}]}, {
           Row[{
             Manipulate`Place[7], 
             Spacer[94], 
             Dynamic[
              If[
               
               And[$CellContext`opa4$$ == 1, $CellContext`f$$ != 
                0], $CellContext`temp1 = Row[{
                  Text[
                   Style["Forces distance = ", 12]], 
                  Dynamic[
                   NumberForm[
                    N[
                    
                    Norm[{$CellContext`rb$$ 
                    Cos[$CellContext`\[Theta]b$$ Degree] - $CellContext`ra$$ 
                    Cos[$CellContext`\[Theta]a$$ Degree], $CellContext`rb$$ 
                    Sin[$CellContext`\[Theta]b$$ Degree] - $CellContext`ra$$ 
                    Sin[$CellContext`\[Theta]a$$ Degree]} - 
                    Projection[{$CellContext`rb$$ 
                    Cos[$CellContext`\[Theta]b$$ Degree] - $CellContext`ra$$ 
                    Cos[$CellContext`\[Theta]a$$ Degree], $CellContext`rb$$ 
                    Sin[$CellContext`\[Theta]b$$ Degree] - $CellContext`ra$$ 
                    Sin[$CellContext`\[Theta]a$$ Degree]}, {$CellContext`f$$ 
                    Cos[$CellContext`\[Phi]d$$ Degree], $CellContext`f$$ 
                    Sin[$CellContext`\[Phi]d$$ Degree]}]]], {3, 2}]]}], 
               Invisible[$CellContext`temp1]]]}]}}, Alignment -> Left, 
         Spacings -> {Automatic, 0.5}]}, 
      "Options" :> {ControlPlacement -> Top}, "DefaultOptions" :> {}],
     ImageSizeCache->{1054., {411., 420.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 TextAlignment->Center]
}, Open  ]]
},
WindowSize->{1920, 997},
Visible->True,
ScrollingOptions->{"VerticalScrollRange"->Fit},
ShowCellBracket->Automatic,
CellContext->Notebook,
TrackCellChangeTimes->False,
Magnification:>1.5 Inherited,
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (July 28, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1486, 35, 199, 7, 230, "Title"],
Cell[1688, 44, 580, 9, 131, "Text"],
Cell[2271, 55, 157, 5, 45, "Text"],
Cell[2431, 62, 351, 6, 102, "Text"],
Cell[2785, 70, 20650, 467, 855, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature 2wDJm3cUgyd6WAgZsLZa1wuU *)
